@@ -18,6 +18,7 @@ type Response struct {
 
 func NewRequest(input string, params structs.Params) (*http.Response, error) {
 	client, err := client.NewClient()
+	
 	if err != nil {
 		fmt.Println(err)
 		os.Exit(0)
@@ -26,19 +27,10 @@ func NewRequest(input string, params structs.Params) (*http.Response, error) {
 	safeInput, _ := json.Marshal(input)
 
 	temperature := "0.5"
-	if params.Temperature != "" {
-		temperature = params.Temperature
-	}
 
 	top_p := "0.5"
-	if params.Top_p != "" {
-		top_p = params.Top_p
-	}
 
 	max_length := "300"
-	if params.Max_length != "" {
-		max_length = params.Max_length
-	}
 
 	var data = strings.NewReader(fmt.Sprintf(`{
 		"prompt": %v,
@@ -49,6 +41,7 @@ func NewRequest(input string, params structs.Params) (*http.Response, error) {
 	`, string(safeInput), temperature, top_p, max_length))
 
 	req, err := http.NewRequest("POST", "https://koboldai-koboldcpp-tiefighter.hf.space/api/extra/generate/stream", data)
+
 	if err != nil {
 		fmt.Println("\nSome error has occurred.")
 		fmt.Println("Error:", err)
@@ -57,6 +50,7 @@ func NewRequest(input string, params structs.Params) (*http.Response, error) {
 	// Setting all the required headers
 	req.Header.Set("Content-Type", "application/json")
 	req.Header.Set("Accept", "application/json")
+
 	// Return response
 	return (client.Do(req))
 }
@@ -68,6 +62,7 @@ func GetMainText(line string) (mainText string) {
 	}
 
 	var d Response
+
 	if err := json.Unmarshal([]byte(obj), &d); err != nil {
 		return ""
 	}
@@ -76,5 +71,6 @@ func GetMainText(line string) (mainText string) {
 		mainText = d.Token
 		return mainText
 	}
+
 	return ""
 }
